'use client'

import React, { useState } from 'react';

// 引入 Server Actions
import { createContainers, stopContainer, removeContainer, getContainerInfo, startContainer } from '@/actions/createContainers';

export default function Home() {
    const [error, setError] = useState<string | null>(null);
    const [message, setMessage] = useState<string | null>(null);

    // 创建容器的函数
    const handleCreateContainers = async () => {
        try {
            const count = 3; // 创建容器的数量
            const baseName = 'my-container'; // 容器名称前缀
            const startingPorts: [number, number] = [5901, 2201]; // VNC 和 SSH 起始端口
            const containers = await createContainers(count, baseName, startingPorts);
            setMessage(`Successfully created ${containers.length} containers.`);
        } catch (err: any) {
            setError(`Error creating containers: ${err.message}`);
        }
    };

    // 停止容器的函数
    const handleStopContainer = async (containerName: string) => {
        try {
            const result = await stopContainer(containerName);
            setMessage(result.message);
        } catch (err: any) {
            setError(`Error stopping container: ${err.message}`);
        }
    };

    // 删除容器的函数
    const handleRemoveContainer = async (containerName: string) => {
        try {
            const result = await removeContainer(containerName);
            setMessage(result.message);
        } catch (err: any) {
            setError(`Error removing container: ${err.message}`);
        }
    };

    // 获取容器信息的函数
    const handleGetContainerInfo = async (containerName: string) => {
        try {
            const info = await getContainerInfo(containerName);
            setMessage(`Container: ${info.containerName}, State: ${info.state}, Ports: ${JSON.stringify(info.ports)}`);
        } catch (err: any) {
            setError(`Error getting container info: ${err.message}`);
        }
    };

    // 启动容器的函数
    const handleStartContainer = async (containerName: string) => {
        try {
            const result = await startContainer(containerName);
            setMessage(result.message);
        } catch (err: any) {
            setError(`Error starting container: ${err.message}`);
        }
    };

    return (
        <div>
            <h1>Container Management</h1>
            {error && <p style={{ color: 'red' }}>{error}</p>}
            {message && <p style={{ color: 'green' }}>{message}</p>}

            <div>
                <button onClick={handleCreateContainers}>Create Containers</button>
                <button onClick={() => handleStopContainer('my-container-0')}>Stop Container</button>
                <button onClick={() => handleRemoveContainer('my-container-0')}>Remove Container</button>
                <button onClick={() => handleGetContainerInfo('my-container-0')}>Get Container Info</button>
                <button onClick={() => handleStartContainer('my-container-0')}>Start Container</button>
            </div>
        </div>
    );
}
